@@ -30,7 +30,6 @@ import org.jboss.errai.common.client.api.Caller;
 import org.jboss.errai.common.client.api.RemoteCallback;
 import org.jboss.errai.ui.client.local.spi.TranslationService;
 import org.kie.workbench.common.widgets.client.popups.validation.ValidationPopup;
-import org.kie.workbench.common.widgets.client.resources.i18n.CommonConstants;
 import org.kie.workbench.common.widgets.metadata.client.KieEditor;
 import org.optaplanner.workbench.screens.solver.client.resources.i18n.SolverEditorConstants;
 import org.optaplanner.workbench.screens.solver.client.type.SolverResourceType;
@@ -47,6 +46,7 @@ import org.uberfire.client.annotations.WorkbenchPartView;
 import org.uberfire.client.views.pfly.multipage.PageImpl;
 import org.uberfire.ext.editor.commons.client.validation.Validator;
 import org.uberfire.ext.editor.commons.service.support.SupportsSaveAndRename;
+import org.uberfire.ext.widgets.common.client.callbacks.CommandErrorCallback;
 import org.uberfire.ext.widgets.common.client.callbacks.HasBusyIndicatorDefaultErrorCallback;
 import org.uberfire.lifecycle.OnClose;
 import org.uberfire.lifecycle.OnMayClose;
@@ -112,17 +112,12 @@ public class SolverEditorPresenter
         SuperDevModeFlag superDevModeFlag = GWT.create(SuperDevModeFlag.class);
         if (superDevModeFlag.isSuperDevModeUsed()) {
             fileMenuBuilder
-                    .addSave(versionRecordManager.newSaveMenuItem(new Command() {
-                        @Override
-                        public void execute() {
-                            onSave();
-                        }
-                    }))
+                    .addSave(versionRecordManager.newSaveMenuItem(this::onSave))
                     .addCopy(versionRecordManager.getCurrentPath(),
-                             fileNameValidator)
+                             getCopyValidator())
                     .addRename(getSaveAndRename())
                     .addDelete(versionRecordManager.getPathToLatest())
-                    .addValidate(onValidate())
+                    .addValidate(getValidateCommand())
                     .addCommand(translationService.getTranslation(SolverEditorConstants.SolverEditorPresenterSmokeTest),
                                 onSmokeTest())
                     .addNewTopLevelMenu(versionRecordManager.buildMenu())
@@ -201,15 +196,12 @@ public class SolverEditorPresenter
         };
     }
 
-    protected Command onValidate() {
-        return new Command() {
-            @Override
-            public void execute() {
-                solverService.call(getRemoteCallback(CommonConstants.INSTANCE.ItemValidatedSuccessfully()))
-                        .validate(versionRecordManager.getCurrentPath(),
-                                  model);
-            }
-        };
+    @Override
+    protected void onValidate(final Command finished) {
+        solverService.call(validationPopup.getValidationCallback(finished),
+                           new CommandErrorCallback(finished)
+        ).validate(versionRecordManager.getCurrentPath(),
+                   model);
     }
 
     private RemoteCallback<List<ValidationMessage>> getRemoteCallback(String message) {
